@@ -1,8 +1,11 @@
 lordif <-
-function(resp.data,group,selection=NULL,criterion="Chisqr",pseudo.R2="McFadden",alpha=0.01,beta.change=0.1,R2.change=0.02,
+function(resp.data,group,selection=NULL,criterion=c("Chisqr","R2","Beta"),pseudo.R2=c("McFadden","Nagelkerke","CoxSnell"),alpha=0.01,beta.change=0.1,R2.change=0.02,
               maxIter=10,minCell=5,minTheta=-4.0,maxTheta=4.0,inc=0.1) {
-if (!(toupper(criterion) %in% c("CHISQR","R2","BETA"))){warning("criterion must be one of the following: \"Chisqr\", \"R2\", or \"Beta\", will be reset to default");criterion<-"Chisqr"}
-if (!(toupper(pseudo.R2) %in% c("MCFADDEN","NAGELKERKE","COXSNELL"))) {warning("pseudo.R2 must be one of the following \"McFadden\", \"Nagelkerke\", or \"CoxSnell\", will be reset to default");pseudo.R2<-"McFadden"}
+call<-match.call()
+criterion<-match.arg(criterion)
+pseudo.R2<-match.arg(pseudo.R2)
+if (!(criterion %in% c("Chisqr","R2","Beta"))){warning("criterion must be one of the following: \"Chisqr\", \"R2\", or \"Beta\", will be reset to default");criterion<-"Chisqr"}
+if (!(pseudo.R2 %in% c("McFadden","Nagerlkerke","CoxSnell"))) {warning("pseudo.R2 must be one of the following \"McFadden\", \"Nagelkerke\", or \"CoxSnell\", will be reset to default");pseudo.R2<-"McFadden"}
 if (alpha<=0 & alpha>1) {warning ("alpha must be > 0 & < 1, will be reset to default");alpha<-.01}
 if (beta.change<=0 & beta.change>=1) {warning ("beta.change must be > 0 & < 1, will be reset to default");beta.change<-.1};
 if (R2.change<=0 & R2.change>=1) {warning("R2.change must be > 0 & < 1, will be reset to default");R2.change<-.035}
@@ -32,7 +35,7 @@ resp.recoded[,i]<-collapse(resp.data[,selection[i]],group,minCell)
 }
 ncat<-as.numeric(apply(resp.recoded,2,max,na.rm=T))
 ng<-length(table(group))
-calib<-grm(resp.recoded,constrained=FALSE,IRT.param=TRUE,control=list(iter.qN=50))
+calib<-grm(resp.recoded,constrained=FALSE,IRT.param=TRUE,control=list(iter.qN=100,GHk=81))
 ipar<-extract(calib)
 theta.grid<-seq(minTheta,maxTheta,inc)
 theta<-calctheta(ipar,resp.recoded,theta.grid)
@@ -94,9 +97,11 @@ theta.sparse<-calctheta(ipar.sparse,sparse.matrix,theta.grid)
 }
 row.names(ipar.sparse)<-names(sparse.matrix)
 }
-return(list(options=list(criterion=criterion,pseudo.R2=pseudo.R2,alpha=alpha,beta.change=beta.change,R2.change=R2.change,
+out<-list(call=call,options=list(criterion=criterion,pseudo.R2=pseudo.R2,alpha=alpha,beta.change=beta.change,R2.change=R2.change,
               maxIter=maxIter,minCell=minCell,minTheta=minTheta,maxTheta=maxTheta,inc=inc),selection=selection,stats=out$stats,
               flag=out$flag,recoded=resp.recoded,group=group,ng=ng,ni=ni,ncat=ncat,calib=theta,calib.sparse=theta.sparse,
-              iteration=iter,ipar=ipar,ipar.sparse=ipar.sparse,stats.raw=outraw$stats,meanraw=meanraw,flag.raw=outraw$flag))
+              iteration=iter,ipar=ipar,ipar.sparse=ipar.sparse,stats.raw=outraw$stats,meanraw=meanraw,flag.raw=outraw$flag)
+class(out)<-"lordif"
+return(out)
 }
 
